local GuildWelcomer = _G['GuildWelcomer'];

function GuildWelcomer:SetupGuilds()
    local numGuilds = GetNumGuilds()
    GuildWelcomer.CurrentGuilds = {}
    for i = 1, numGuilds do
        local name = GetGuildName(i)
        GuildWelcomer.CurrentGuilds[i] = name
        local saved = GuildWelcomer.Saved.Guilds[name]
        GuildWelcomer.Saved.Guilds[name] = (saved~=nil and saved or {})
    end
end

function GuildWelcomer:OnGuildMemberAdded(guildId, playerName)
    local guildIdNum = tonumber(guildId)
    local guildName = GetGuildName(guildIdNum)
    local guildSettings = GuildWelcomer.Saved.Guilds[guildName]
    if guildSettings and guildSettings.AutoWelcome then
        local template = zo_strformat(guildSettings.Message)
        if not template or template == '' then return end -- Empty empty string
        
        local message = string.gsub(template, "%%PLAYER%%", playerName)
        local formattedMessage = '/g' .. guildId .. ' ' .. message
        
        ZO_ChatWindowTextEntryEditBox:SetText(formattedMessage)
        
        if GuildWelcomer.Saved.DoPlaySound then
            PlaySound(SOUNDS.VOICE_CHAT_MENU_CHANNEL_MADE_ACTIVE)
        end
    end
end

function Initialized(eventCode, addonName)
    if addonName ~= "GuildWelcomer" then return end
    
    local defaults = {Guilds = {}, DoPlaySound = true, SoundIndex = SOUNDS.VOICE_CHAT_MENU_CHANNEL_MADE_ACTIVE}
    GuildWelcomer.Saved = ZO_SavedVars:NewAccountWide(GuildWelcomer.SavedVarNamespace, GuildWelcomer.SavedVarVersion, nil, defaults)

    GuildWelcomer.SetupGuilds()
    GuildWelcomer.CreateSettingsWindow()

    EVENT_MANAGER:RegisterForEvent(GuildWelcomer.EventNamespace, EVENT_GUILD_MEMBER_ADDED, GuildWelcomer.OnGuildMemberAdded)
end

EVENT_MANAGER:RegisterForEvent(GuildWelcomer.EventNamespace, EVENT_ADD_ON_LOADED, Initialized) -- The whole file was parsed - time to fire!